@@ -25,5 +25,10 @@ class DocumentRTF(BaseDocument):
             report.write(new_text)
 
     def set_params(self, params):
+        """
+        Подстановка параметров
+        :param params: словарь с параметрами отчета
+        :result: None
+        """
         assert isinstance(params, dict), 'wrong params type'
         self.converted_dictionary = convert_dict(params)
