@@ -8,6 +8,7 @@ from simple_report.xls.output_options import XSL_OUTPUT_SETTINGS
 
 class DocumentXLS(BaseDocument, SpreadsheetDocument):
     """
+    Обертка для отчетов в формате XLS
     """
 
     def __init__(self, ffile, tags=None, **kwargs):
@@ -16,9 +17,18 @@ class DocumentXLS(BaseDocument, SpreadsheetDocument):
 
     @property
     def workbook(self):
+        """
+         Получение рабочей книги
+        :result: рабочая книга
+        """
         return self._workbook
 
     def build(self, dst):
+        """
+         Сборка отчета
+        :param dst: путь до выходного файла
+        :result:
+        """
         self._workbook.build(dst)
 
     def __setattr__(self, key, value):
@@ -26,4 +36,4 @@ class DocumentXLS(BaseDocument, SpreadsheetDocument):
         if key in XSL_OUTPUT_SETTINGS:
             setattr(self._workbook, key, value)
         else:
-            super(DocumentXLS, self).__setattr__(key, value)
\ No newline at end of file
+            super(DocumentXLS, self).__setattr__(key, value)
