@@ -1,4 +1,4 @@
-#coding: utf-8
+# coding: utf-8
 from simple_report.core.document_wrap import DocumentOpenXML, SpreadsheetDocument
 from simple_report.xlsx.spreadsheet_ml import CommonPropertiesXLSX
 
@@ -6,6 +6,7 @@ __author__ = 'prefer'
 
 class DocumentXLSX(DocumentOpenXML, SpreadsheetDocument):
     u"""
+    Обертка для работы с форматом XLSX
     """
 
     def __init__(self, *args, **kwargs):
@@ -14,10 +15,17 @@ class DocumentXLSX(DocumentOpenXML, SpreadsheetDocument):
 
     @property
     def workbook(self):
+        u"""
+        Книга для таблицы
+        """
         return self.common_properties.main
 
     def build(self, dst_file):
         """
+        Сохранение отчета в файл
+        
+        :param dst_file: путь до выходного файла
+        :type dst_file: str
         """
         self.workbook.build()
         super(DocumentXLSX, self).build(dst_file)
