@@ -16,6 +16,7 @@ from simple_report.xlsx.formula import Formula
 from simple_report.utils import ColumnHelper, date_to_float, FormulaWriteExcel
 from simple_report.xls.section import XLSImage
 
+
 sys.path.append('.')
 
 from test_oo_wrapper import TestOO
@@ -732,23 +733,101 @@ class TestWriteXLSX(unittest.TestCase):
         return report.build(dst)
 
 
-
-
-class TestWindowsXLSX(TestXLSX, unittest.TestCase):
-    SUBDIR = 'win'
-
-
-class TestLinuxDOCX(unittest.TestCase):
+class TestWriteXLS(unittest.TestCase):
     """
-
+    Тестируем правильность вывода для XSL
     """
+    SUBDIR = 'linux'
 
     def setUp(self):
+        assert self.SUBDIR
+        self.src_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                    'test_data', self.SUBDIR, 'xls', )
+        self.dst_dir = self.src_dir
+
+        self.test_files = dict([(path, os.path.join(self.src_dir, path))
+                                for path in os.listdir(self.src_dir)
+                               if path.startswith('test')])
+
+    def test_left_down(self, report=None):
+        if report is None:
+            return
+        for i in range(2):
+            section1 = report.get_section('Section1')
+            section1.flush({'section1': i}, oriented=Section.LEFT_DOWN)
+            self.assertEqual(section1.sheet_data.cursor.row, (0, 2 * i + 2))
+            self.assertEqual(section1.sheet_data.cursor.column, (2, 2 * i))
+
+    def test_left_down2(self, report=None):
+        if report is None:
+            return
+        for i in range(2):
+            section3 = report.get_section('Section3')
+            section3.flush({'section3': 100}, oriented=Section.LEFT_DOWN)
+            self.assertEqual(section3.sheet_data.cursor.row, (0, 2 * i + 10))
+            self.assertEqual(section3.sheet_data.cursor.column, (2, 2 * i + 8))
+
+    def test_right_up(self, report=None):
+        if report is None:
+            return
+        section1 = report.get_section('Section1')
+        section1.flush({'section1': 2}, oriented=Section.RIGHT_UP)
+        self.assertEqual(section1.sheet_data.cursor.row, (2, 2))
+        self.assertEqual(section1.sheet_data.cursor.column, (4, 0))
+
+    def test_vertical(self, report=None):
+        if report is None:
+            return
+        for i in range(3):
+            section2 = report.get_section('Section2')
+            section2.flush({'section2': i}, oriented=Section.VERTICAL)
+            self.assertEqual(section2.sheet_data.cursor.row,
+                             (2, 2 * (i + 1) + 2))
+            self.assertEqual(section2.sheet_data.cursor.column,
+                             (4, 2 * (i + 1)))
+
+    def test_horizontal(self, report=None):
+        if report is None:
+            return
+        for i in range(3):
+            section3 = report.get_section('Section3')
+            section3.flush({'section3': i}, oriented=Section.HORIZONTAL)
+            self.assertEqual(section3.sheet_data.cursor.row, (2, 8))
+            self.assertEqual(section3.sheet_data.cursor.column,
+                             (6 + 2 * i, 6))
+
+    def test_report_write(self):
+
+        src = self.test_files['test-report-output.xls']
+        dst = os.path.join(self.dst_dir, 'res-report-output.xls')
+        if os.path.exists(dst):
+            os.remove(dst)
+
+        report = SpreadsheetReport(src, wrapper=DocumentXLS,
+                                   type=FileConverter.XLS)
+        self.test_left_down(report)
+        self.test_right_up(report)
+        self.test_vertical(report)
+        self.test_horizontal(report)
+        self.test_left_down2(report)
+
+        return report.build(dst)
+
+
+class TestReportFormatXLS(unittest.TestCase):
+    """
+    Тест на работоспособность отчета формата XLS
+    """
+
+    SUBDIR = 'linux'
+
+    def setUp(self):
+        assert self.SUBDIR
         self.src_dir = os.path.join(
             os.path.dirname(os.path.abspath(__file__)),
             'test_data',
-            'linux',
-            'docx'
+            self.SUBDIR,
+            'xls'
         )
         self.dst_dir = self.src_dir
 
@@ -756,212 +835,209 @@ class TestLinuxDOCX(unittest.TestCase):
                                 for path in os.listdir(self.src_dir)
                                 if path.startswith('test')])
 
-    def test_simple_docx(self):
+    def test_spreadsheet_with_flag(self):
         """
+        Тест на использование класса SpreadsheetReport с переданным в
+        конструктор wrapper-ом.
         """
 
-        template_name = 'test-sluzh.docx'
-        path = self.test_files[template_name]
-        doc = DocumentReport(path)
+        src = self.test_files['test_xls.xls']
+        dst = os.path.join(self.dst_dir, 'res-test_xls.xls')
+        if os.path.exists(dst):
+            os.remove(dst)
 
-        res_file_name = 'res-' + template_name
-        dst = os.path.join(self.dst_dir, res_file_name)
+        report = SpreadsheetReport(src, wrapper=DocumentXLS,
+                                   type=FileConverter.XLS)
 
-        doc.build(dst, {'Employee_name': u'Иванов И.И.',
-                        'region_name': u'Казань'})
-        self.assertEqual(os.path.exists(dst), True)
+        section1 = report.get_section('Section1')
+        section1.flush({'tag1': 1})
 
-    def test_spreadsheet_docx(self):
+        report.workbook.active_sheet = 1
+
+        section2 = report.get_section('Section2')
+        for i in range(10):
+            section2.flush({'tag2': i})
+
+        for i in range(10):
+            section2.flush({'tag2': str(10)}, oriented=Section.HORIZONTAL)
+
+        return report.build(dst)
+
+    def test_with_merge(self):
         """
-        Текст внутри таблицы
+        Конструкция with merge для обьединения ячеек вывода
         """
 
-        template_name = 'test_spreadsheet.docx'
-        path = self.test_files[template_name]
-        doc = DocumentReport(path)
+        src = self.test_files['test_merge.xls']
+        dst = os.path.join(self.dst_dir, 'res-merge.xls')
+        if os.path.exists(dst):
+            os.remove(dst)
 
-        res_file_name = 'res-' + template_name
-        dst = os.path.join(self.dst_dir, res_file_name)
+        report = SpreadsheetReport(src, wrapper=DocumentXLS,
+                                   type=FileConverter.XLS)
 
-        tag1 = doc.get_all_parameters().next()
-        self.assertEqual(tag1, '#sometext#')
+        s1 = report.get_section('s1')
+        s2 = report.get_section('s2')
+        s3 = report.get_section('s3')
+        s4 = report.get_section('s4')
+        s5 = report.get_section('s5')
 
-        doc.build(dst, {'sometext': u'Некий текст'})
-        self.assertEqual(os.path.exists(dst), True)
+        s5.flush({'p5': 1}, oriented=ISpreadsheetSection.VERTICAL)
+        s5.flush({'p5': 2}, oriented=ISpreadsheetSection.VERTICAL)
+        s5.flush({'p5': 3}, oriented=ISpreadsheetSection.HORIZONTAL)
 
-    def test_picture_docx(self):
+        m1 = MergeXLS(s1, s2, {'p1': 1},
+                      oriented=ISpreadsheetSection.HORIZONTAL)
+        with m1:
+            m2 = MergeXLS(s2, s3, {'p21': 1, 'p22': 21},
+                          oriented=ISpreadsheetSection.HORIZONTAL)
+            with m2:
+                m3 = MergeXLS(s3, s4, {'p3': 1},
+                              oriented=ISpreadsheetSection.HORIZONTAL)
+                with m3:
+                    s4.flush({'p4': 1}, oriented=ISpreadsheetSection.RIGHT)
+                    for i in range(2, 4):
+                        s4.flush({'p4': i},
+                                 oriented=ISpreadsheetSection.VERTICAL)
+
+                m3_exp = (m3._begin_merge_col == 9
+                          and m3._end_merge_col == 9
+                          and m3.begin_row_merge == 3
+                          and m3.end_row_merge == 5)
+                self.assertEqual(m3_exp, True)
+
+                m3 = MergeXLS(s3, s4, {'p3': 2},
+                              oriented=ISpreadsheetSection.HIERARCHICAL)
+                with m3:
+                    s4.flush({'p4': 1}, oriented=ISpreadsheetSection.RIGHT)
+                    s4.flush({'p4': 2}, oriented=ISpreadsheetSection.VERTICAL)
+
+            m2 = MergeXLS(s2, s3, {'p21': 2, 'p22': 21},
+                          oriented=ISpreadsheetSection.HIERARCHICAL)
+            with m2:
+                m3 = MergeXLS(s3, s4, {'p3': 1},
+                              oriented=ISpreadsheetSection.HORIZONTAL)
+                with m3:
+                    s4.flush({'p4': 1}, oriented=ISpreadsheetSection.RIGHT)
+                    s4.flush({'p4': 2}, oriented=ISpreadsheetSection.VERTICAL)
+
+        m1_exp = (m1._begin_merge_col == 6 and m1._end_merge_col == 6
+                  and m1.begin_row_merge == 3 and m1.end_row_merge == 9)
+        self.assertEqual(m1_exp, True)
+
+        m1 = MergeXLS(s1, s2, {'p1': 2},
+                      oriented=ISpreadsheetSection.HIERARCHICAL)
+        with m1:
+            m2 = MergeXLS(s2, s3, {'p21': 1, 'p22': 21},
+                          oriented=ISpreadsheetSection.HORIZONTAL)
+            with m2:
+                m3 = MergeXLS(s3, s4, {'p3': 1},
+                              oriented=ISpreadsheetSection.HORIZONTAL)
+                with m3:
+                    s4.flush({'p4': 1},
+                             oriented=ISpreadsheetSection.HORIZONTAL)
+
+        return report.build(dst)
+
+    def test_xls_formula_generation(self):
         """
-        Текст внутри прямоугольника
+        Генерация формул в xls
         """
+        src = self.test_files['test-formula_generation.xls']
+        dst = os.path.join(self.dst_dir, 'res-formula_generation.xls')
+        if os.path.exists(dst):
+            os.remove(dst)
 
-        template_name = 'test_rect.docx'
-        path = self.test_files[template_name]
-        doc = DocumentReport(path)
+        report = SpreadsheetReport(src, wrapper=DocumentXLS,
+                                   type=FileConverter.XLS)
 
-        res_file_name = 'res-' + template_name
-        dst = os.path.join(self.dst_dir, res_file_name)
+        row_insert_formula_section = report.get_section('row_insert_formula')
+        check_insert_formula_section = report.get_section(
+            'check_insert_formula'
+        )
 
-        tags = []
-        for tag in doc.get_all_parameters():
-            tags.append(tag)
-
-        self.assertFalse(tags[0] != '#brandgroupname#'
-                         and tags[0] != '#category#')
-        self.assertFalse(tags[1] != '#brandgroupname#'
-                         and tags[1] != '#category#')
-
-        doc.build(dst, {'brandgroupname': u'Брэнд', 'category': u'Категория'})
-        self.assertEqual(os.path.exists(dst), True)
-
-    def test_picture_shape(self):
-
-        template_name = 'test_pict_shape_2.docx'
-        path = self.test_files[template_name]
-
-        res_file_name = 'res-pict_shape.docx'
-        dst = os.path.join(self.dst_dir, res_file_name)
-
-        report = DocumentReport(path)
-        params = {}
-
-        params['fname'] = '1'
-        params['sname'] = '2'
-        params['pname'] = '3'
-        params['issued_by'] = '4'
-        params['date_of_birth'] = '5'
-
-        params['date_start_day'] = '6'
-        params['date_start_month'] = '7'
-        params['date_start_year'] = '8'
-        params['date_start'] = '9'
-        params['date_end_day'] = '10'
-        params['date_end_month'] = '11'
-        params['date_end_year'] = '12'
-        params['date_end'] = '13'
-        params['region_number'] = '14'
-        params['date_start_plus'] = '15'
-        params['date_start_plus_day'] = '16'
-        params['date_start_plus_month'] = '17'
-        params['date_start_plus'] = '18'
-        params['date_start_plus_year'] = '19'
-        params['habaddr'] = '20'
-        params['regaddr1'] = '21'
-        params['regaddr2'] = '22'
-        params['regaddr3'] = '23'
-        params['inspect1'] = '24'
-        params['inspect2'] = '25'
-        params['is_AI'] = u"AI"
-        params['is_AII'] = u"AII"
-        params['is_AIII'] = u"AIII"
-        params['is_AIV'] = u"AIV"
-        params['is_B'] = u"B"
-        params['is_C'] = u"C"
-        params['is_D'] = u"D"
-        params['is_E'] = u"E"
-        params['is_F'] = u"F"
-        params['#komment#'] = 'd'
-
-        report.build(dst, params)
-
-        self.assertEqual(os.path.exists(dst), True)
-
-    def test_tables_flush(self):
-        template_name = 'test_table.docx'
-        path = self.test_files[template_name]
-
-        res_file_name = 'res-table_flush.docx'
-        dst = os.path.join(self.dst_dir, res_file_name)
-
-        report = DocumentReport(path)
-        # report.set_docx_table_sections()
-        s1 = report.get_section('section1')
-        s2 = report.get_section('section2')
-        s2.flush({'test': u'Lorem ipsum'})
-        s1.flush({
-            'test_table_row1col1': u'Hello',
-            'test_table_row1col2': u'simple_report',
-            'test_table_row1col3': u'user',
-            'test_table_row1col4': LOREM_IPSUM,
-        })
-        params = {}
-        report.build(dst, params)
-
-    def test_table_section_double(self):
-        template_name = 'test_table_double_section.docx'
-        path = self.test_files[template_name]
-
-        report = DocumentReport(path)
-        try:
-            report.get_section('section1')
-        except SectionException:
-            pass
+        insert_formulas(row_insert_formula_section,
+                       check_insert_formula_section)
+        report.build(dst)
+        check_file = " Please, check output file %s with table proc." % dst
+        if os.name == 'posix':
+            openoffice = '/usr/bin/openoffice'
+            libreoffice = '/usr/bin/libreoffice'
+            office = None
+            if os.path.exists(libreoffice):
+                office = libreoffice
+            elif os.path.exists(openoffice):
+                office = openoffice
+            assert office, ("Didn't found neither openoffice nor libreoffice" +
+                            check_file)
+            subprocess.call([office, dst])
+        elif os.name == 'nt':
+            subprocess.call(['EXCEL.exe', dst])
+        # elif os.name == 'mac':
         else:
-            raise Exception('Docx tables sections doubling test failed')
+            raise Exception("Can't check xls formula generation.")
 
-    def test_divisible_keys(self):
-        template_name = 'test_divisibles.docx'
-        path = self.test_files[template_name]
-        report = DocumentReport(path)
-        res_file_name = 'res-divisibles.docx'
-        dst = os.path.join(self.dst_dir, res_file_name)
-        params = {
-            "tasks": "",
-            "kind_tostring": u"документарная и выездная",
-            "normative_list": "",
-            "finish_date": "13.12.2012",
-            "expert_list": "",
-            "docs": "",
-            "num": "1",
-            "purpose": "",
-            "address": u"420101, Респ Татарстан (Татарстан), г Казань, ул Карбышева, д. 37, кв. 44",
-            "events": "",
-            "subject3": "x",
-            "articles": "",
-            "inspectors_list": "",
-            "supervisionobj_name": u"Малыши и малышки",
-            "oyear": 2013,
-            "type_tostring": u"внеплановая",
-            "start_date": "14.02.2013",
-            "subject1": "x",
-            "subject2": "x",
-            "oday": 21,
-            "subject4": "x",
-            "subject5": "x",
-            "subject6": "x",
-            "subject7": "x",
-            "authority_parent": "",
-            "omonth": 3
-        }
-        report.build(dst, params)
+    def test_xls_image_insertion(self):
+        """
+        Вставка изображений
+        """
+        src = self.test_files['test_insert_image.xls']
+        src_image1 = self.test_files['test_image1.bmp']
+        src_image2 = self.test_files['test_image2.bmp']
+        dst = os.path.join(self.dst_dir, 'res-insert_image.xls')
+        if os.path.exists(dst):
+            os.remove(dst)
 
-    def test_flush_order(self):
-        template_name = 'test_flush_order.docx'
-        path = self.test_files[template_name]
-        report = DocumentReport(path)
-        res_file_name = 'res-flush_order.docx'
-        dst = os.path.join(self.dst_dir, res_file_name)
-        params = {
-            "example": "output_one",
-            "example_two": "ouput_two",
-            "example_two_three": "output_two_three",
-            "exampl": "no_output"
-        }
-        report.build(dst, params)
+        report = SpreadsheetReport(src, wrapper=DocumentXLS,
+                                   type=FileConverter.XLS)
 
-    def test_tabs(self):
-        template_name = 'test_tabs.docx'
-        path = self.test_files[template_name]
-        report = DocumentReport(path)
-        res_file_name = 'res-tabs.docx'
-        dst = os.path.join(self.dst_dir, res_file_name)
-        params = {
-            "tfoms_to": "TFOMS",
-            "tfoms_to_address": "TFOMS_ADDRESS",
-            "tfoms_to_director_fio": "TFOMS_TO_DIR_FIO"
-        }
-        report.build(dst, params)
+        row_section = report.get_section('row')
+        row_section.flush({
+            'image1': XLSImage(src_image1)
+        })
+        row_section.flush({
+            'image2': XLSImage(src_image2)
+        })
+        row_section.flush({
+            'image1': XLSImage(src_image2),
+            'image2': XLSImage(src_image1)
+        })
+        report.build(dst)
+
+    def test_rows_height(self):
+        """
+        Тест на выставление высоты строк
+        """
+        src = self.test_files['test_rows_height.xls']
+        dst = os.path.join(self.dst_dir, 'res-rows-height.xls')
+
+        if os.path.exists(dst):
+            os.remove(dst)
+        report = SpreadsheetReport(
+            src,
+            wrapper=DocumentXLS,
+            type=FileConverter.XLS
+        )
+        report.get_section('row1').flush({
+            't1': LOREM_IPSUM[:20],
+            't2': u'. '.join([
+                u'Проверка на автоподбор высоты',
+                LOREM_IPSUM
+            ])
+        })
+
+        report.get_section('row2').flush({
+            't1': LOREM_IPSUM[:20],
+           't2': u'. '.join([
+                u'Проверка на высоту строки, взятую из шаблона',
+                LOREM_IPSUM
+            ])
+        })
+        report.build(dst)
 
 
+class TestWindowsXLSX(TestXLSX, unittest.TestCase):
+    SUBDIR = 'win'
 
 
 class TestUtils(unittest.TestCase):
